@@ -14,7 +14,7 @@
 
 # /// script
 # dependencies = [
-#     "transformers==4.56.2",
+#     "transformers==4.57.0",
 #     "albumentations >= 1.4.16",
 #     "timm",
 #     "datasets",
@@ -50,14 +50,14 @@ from transformers import (
 from transformers.image_processing_utils import BatchFeature
 from transformers.trainer import EvalPrediction
 from transformers.trainer_utils import get_last_checkpoint
-from transformers.utils import check_min_version, send_example_telemetry
+from transformers.utils import check_min_version
 from transformers.utils.versions import require_version
 
 
 logger = logging.getLogger(__name__)
 
 # Will error if the minimal version of Transformers is not installed. Remove at your own risks.
-check_min_version("4.56.0")
+check_min_version("4.57.0")
 
 require_version("datasets>=2.0.0", "To fix: pip install -r examples/pytorch/instance-segmentation/requirements.txt")
 
@@ -367,10 +367,6 @@ def main():
     training_args.batch_eval_metrics = True
     training_args.remove_unused_columns = False
 
-    # # Sending telemetry. Tracking the example usage helps us better allocate resources to maintain them. The
-    # # information sent is the one passed as arguments along with your Python/PyTorch versions.
-    send_example_telemetry("run_instance_segmentation", args)
-
     # Setup logging and log on each process the small summary:
     setup_logging(training_args)
     logger.warning(
