@@ -19,6 +19,9 @@ from collections import defaultdict
 from functools import lru_cache
 from typing import Optional, Union
 
+import torch
+from torchvision.transforms.v2 import functional as F
+
 from ...image_processing_utils import BatchFeature
 from ...image_processing_utils_fast import (
     BaseImageProcessorFast,
@@ -31,22 +34,9 @@ from ...processing_utils import Unpack
 from ...utils import (
     TensorType,
     auto_docstring,
-    is_torch_available,
-    is_torchvision_available,
-    is_torchvision_v2_available,
 )
 
 
-if is_torch_available():
-    import torch
-
-if is_torchvision_available():
-    if is_torchvision_v2_available():
-        from torchvision.transforms.v2 import functional as F
-    else:
-        from torchvision.transforms import functional as F
-
-
 def get_factors(dividend: int) -> set[int]:
     """
     Calculate all factors of a given number, i.e. a divisor that leaves
@@ -198,7 +188,7 @@ def pad_to_best_fit(
         background_color (`int` or `tuple[int, int, int]`, *optional*, defaults to 0):
             The color to use for the padding. Can be an integer for single channel or a
             tuple of integers representing for multi-channel images. If passed as integer
-            in mutli-channel mode, it will default to `0` in subsequent channels.
+            in multi-channel mode, it will default to `0` in subsequent channels.
     Returns:
         `torch.Tensor`: The padded images.
     """
