@@ -186,7 +186,7 @@ class TextGenerationPipeline(Pipeline):
             generate_kwargs["prefix_length"] = prefix_inputs["input_ids"].shape[-1]
 
         if handle_long_generation is not None:
-            if handle_long_generation not in {"hole"}:
+            if handle_long_generation != "hole":
                 raise ValueError(
                     f"{handle_long_generation} is not a valid value for `handle_long_generation` parameter expected"
                     " [None, 'hole']"
@@ -241,7 +241,7 @@ class TextGenerationPipeline(Pipeline):
         Parse arguments and tokenize
         """
         # Parse arguments
-        if self.model.__class__.__name__ in ["TransfoXLLMHeadModel"]:
+        if self.model.__class__.__name__ == "TransfoXLLMHeadModel":
             kwargs.update({"add_space_before_punct_symbol": True})
 
         return super()._parse_and_tokenize(*args, **kwargs)
@@ -483,16 +483,16 @@ class TextGenerationPipeline(Pipeline):
         generated_sequence = generated_sequence.numpy().tolist()
         records = []
         other_outputs = model_outputs.get("additional_outputs", {})
-        splitted_keys = {}
+        split_keys = {}
         if other_outputs:
             if self.framework == "pt":
                 for k, v in other_outputs.items():
                     if isinstance(v, torch.Tensor) and v.shape[0] == len(generated_sequence):
-                        splitted_keys[k] = v.numpy().tolist()
+                        split_keys[k] = v.numpy().tolist()
             elif self.framework == "tf":
                 for k, v in other_outputs.items():
                     if isinstance(v, tf.Tensor) and v.shape[0] == len(generated_sequence):
-                        splitted_keys[k] = v.numpy().tolist()
+                        split_keys[k] = v.numpy().tolist()
 
         skip_special_tokens = skip_special_tokens if skip_special_tokens is not None else True
         for idx, sequence in enumerate(generated_sequence):
@@ -539,7 +539,7 @@ class TextGenerationPipeline(Pipeline):
                             # When we're not starting from a prefill, the output is a new assistant message
                             all_text = list(prompt_text.messages) + [{"role": "assistant", "content": all_text}]
                 record = {"generated_text": all_text}
-                for key, values in splitted_keys.items():
+                for key, values in split_keys.items():
                     record[key] = values[idx]
             records.append(record)
 
