@@ -18,12 +18,12 @@ import re
 import shutil
 import tempfile
 import unittest
-from functools import lru_cache
+from functools import cached_property
 
 from transformers import AddedToken, BatchEncoding, ByT5Tokenizer
-from transformers.utils import cached_property, is_tf_available, is_torch_available
+from transformers.utils import is_tf_available, is_torch_available
 
-from ...test_tokenization_common import TokenizerTesterMixin, use_cache_if_possible
+from ...test_tokenization_common import TokenizerTesterMixin
 
 
 if is_torch_available():
@@ -49,8 +49,6 @@ class ByT5TokenizationTest(TokenizerTesterMixin, unittest.TestCase):
         return ByT5Tokenizer.from_pretrained("google/byt5-small")
 
     @classmethod
-    @use_cache_if_possible
-    @lru_cache(maxsize=64)
     def get_tokenizer(cls, pretrained_name=None, **kwargs) -> ByT5Tokenizer:
         pretrained_name = pretrained_name or cls.tmpdirname
         return cls.tokenizer_class.from_pretrained(pretrained_name, **kwargs)
