@@ -32,7 +32,6 @@ from ...generation.test_utils import GenerationTesterMixin
 from ...test_configuration_common import ConfigTester
 from ...test_modeling_common import (
     ModelTesterMixin,
-    _config_zero_init,
     ids_tensor,
     random_attention_mask,
 )
@@ -501,36 +500,6 @@ class ClvpModelForConditionalGenerationTest(ModelTesterMixin, unittest.TestCase)
     def test_model_get_set_embeddings(self):
         pass
 
-    # override as the `logit_scale` parameter initialization is different for Clvp
-    def test_initialization(self):
-        config, inputs_dict = self.model_tester.prepare_config_and_inputs_for_common()
-
-        configs_no_init = _config_zero_init(config)
-        for model_class in self.all_model_classes:
-            model = model_class(config=configs_no_init)
-            for name, param in model.named_parameters():
-                if param.requires_grad:
-                    # check if `logit_scale` is initialized as per the original implementation
-                    if name == "logit_scale":
-                        expected_value = np.log(1 / 0.07)
-                        returned_value = param.data.item()
-
-                        self.assertAlmostEqual(
-                            returned_value,
-                            expected_value,
-                            delta=1e-3,
-                            msg=f"Parameter {name} of model {model_class} seems not properly initialized",
-                        )
-                    else:
-                        expected_range = [0.0, 1.0]
-                        returned_range = ((param.data.mean() * 1e9).round() / 1e9).item()
-
-                        self.assertIn(
-                            returned_range,
-                            expected_range,
-                            msg=f"Parameter {name} of model {model_class} seems not properly initialized",
-                        )
-
     def test_load_speech_text_decoder_config(self):
         config, inputs_dict = self.model_tester.prepare_config_and_inputs_for_common()
 
