@@ -14,9 +14,9 @@
 
 
 import unittest
+from functools import cached_property
 
 from transformers import CodeGenConfig, is_torch_available
-from transformers.file_utils import cached_property
 from transformers.testing_utils import backend_manual_seed, require_torch, slow, torch_device
 
 from ...generation.test_utils import GenerationTesterMixin
@@ -379,7 +379,7 @@ class CodeGenModelTest(ModelTesterMixin, GenerationTesterMixin, PipelineTesterMi
         model.config.pad_token_id = model.config.eos_token_id
 
         # use different length sentences to test batching
-        sentences = ["def hellow_world():", "def greet(name):"]
+        sentences = ["def hello_world():", "def greet(name):"]
 
         inputs = tokenizer(sentences, return_tensors="pt", padding=True)
         input_ids = inputs["input_ids"].to(torch_device)
@@ -415,7 +415,7 @@ class CodeGenModelTest(ModelTesterMixin, GenerationTesterMixin, PipelineTesterMi
         padded_sentence = tokenizer.decode(output_padded[0], skip_special_tokens=True)
 
         expected_output_sentence = [
-            'def hellow_world():\n    print("Hello World")\n\nhellow_world()',
+            'def hello_world():\n    print("Hello World")\n\nhellow_world()',
             'def greet(name):\n    print(f"Hello {name}")\n\ng',
         ]
         self.assertListEqual(expected_output_sentence, batch_out_sentence)
