@@ -354,27 +354,28 @@ class DacModelTest(ModelTesterMixin, PipelineTesterMixin, unittest.TestCase):
             dict_inputs = self._prepare_for_class(inputs_dict, model_class)
             check_equivalence(model, tuple_inputs, dict_inputs)
 
-    # Ignore copy
-    def test_initialization(self):
-        config, inputs_dict = self.model_tester.prepare_config_and_inputs_for_common()
-
-        configs_no_init = _config_zero_init(config)
-        for model_class in self.all_model_classes:
-            model = model_class(config=configs_no_init)
-            for name, param in model.named_parameters():
-                uniform_init_parms = ["conv", "in_proj", "out_proj", "codebook"]
-                if param.requires_grad:
-                    if any(x in name for x in uniform_init_parms):
-                        self.assertTrue(
-                            -1.0 <= ((param.data.mean() * 1e9).round() / 1e9).item() <= 1.0,
-                            msg=f"Parameter {name} of model {model_class} seems not properly initialized",
-                        )
-
     def test_identity_shortcut(self):
         config, inputs_dict = self.model_tester.prepare_config_and_inputs()
         config.use_conv_shortcut = False
         self.model_tester.create_and_check_model_forward(config, inputs_dict)
 
+    def test_quantizer_from_latents(self):
+        config, inputs_dict = self.model_tester.prepare_config_and_inputs()
+        model = DacModel(config=config).to(torch_device).eval()
+        self.assertTrue(
+            all(hasattr(quantizer, "codebook_dim") for quantizer in model.quantizer.quantizers),
+            msg="All quantizers should have the attribute codebook_dim",
+        )
+        with torch.no_grad():
+            encoder_outputs = model.encode(inputs_dict["input_values"])
+            latents = encoder_outputs.projected_latents
+            quantizer_representation, quantized_latents = model.quantizer.from_latents(latents=latents)
+
+        self.assertIsInstance(quantizer_representation, torch.Tensor)
+        self.assertIsInstance(quantized_latents, torch.Tensor)
+        self.assertEqual(quantized_latents.shape[0], latents.shape[0])
+        self.assertEqual(quantized_latents.shape[1], latents.shape[1])
+
 
 # Copied from transformers.tests.encodec.test_modeling_encodec.normalize
 def normalize(arr):
@@ -872,3 +873,39 @@ class DacIntegrationTest(unittest.TestCase):
             # make sure forward and decode gives same result
             enc_dec = model(inputs["input_values"])[1]
             torch.testing.assert_close(decoded_outputs["audio_values"], enc_dec, rtol=1e-6, atol=1e-6)
+
+    @parameterized.expand([(model_name,) for model_name in EXPECTED_PREPROC_SHAPE_BATCH.keys()])
+    def test_quantizer_from_latents_integration(self, model_name):
+        model_id = f"descript/{model_name}"
+        model = DacModel.from_pretrained(model_id).to(torch_device)
+        processor = AutoProcessor.from_pretrained(model_id)
+
+        # load audio sample
+        librispeech_dummy = load_dataset("hf-internal-testing/librispeech_asr_dummy", "clean", split="validation")
+        librispeech_dummy = librispeech_dummy.cast_column("audio", Audio(sampling_rate=processor.sampling_rate))
+        audio_sample = librispeech_dummy[0]["audio"]["array"]
+
+        # check on processor audio shape
+        inputs = processor(
+            raw_audio=audio_sample,
+            sampling_rate=processor.sampling_rate,
+            return_tensors="pt",
+        ).to(torch_device)
+
+        input_values = inputs["input_values"]
+        with torch.no_grad():
+            encoder_outputs = model.encode(input_values)
+            latents = encoder_outputs.projected_latents
+
+            # reconstruction using from_latents
+            quantizer_representation, quantized_latents = model.quantizer.from_latents(latents=latents)
+            reconstructed = model.decode(quantized_representation=quantizer_representation).audio_values
+
+            # forward pass
+            original_reconstructed = model(input_values).audio_values
+
+        # ensure forward and decode are the same
+        self.assertTrue(
+            torch.allclose(reconstructed, original_reconstructed, atol=1e-6),
+            msg="Reconstructed codes from latents should match original quantized codes",
+        )
