@@ -15,6 +15,7 @@
 
 import unittest
 import warnings
+from functools import cached_property
 
 from transformers import DeiTConfig
 from transformers.testing_utils import (
@@ -26,7 +27,7 @@ from transformers.testing_utils import (
     slow,
     torch_device,
 )
-from transformers.utils import cached_property, is_torch_available, is_vision_available
+from transformers.utils import is_torch_available, is_vision_available
 
 from ...test_configuration_common import ConfigTester
 from ...test_modeling_common import ModelTesterMixin, floats_tensor, ids_tensor
