@@ -18,7 +18,7 @@ import unittest
 import pytest
 from packaging import version
 
-from transformers import AutoModelForCausalLM, AutoTokenizer, GemmaConfig, is_torch_available
+from transformers import AutoModelForCausalLM, AutoTokenizer, is_torch_available
 from transformers.generation.configuration_utils import GenerationConfig
 from transformers.testing_utils import (
     DeviceProperties,
@@ -30,7 +30,6 @@ from transformers.testing_utils import (
     require_read_token,
     require_torch,
     require_torch_accelerator,
-    require_torch_gpu,
     slow,
     torch_device,
 )
@@ -51,21 +50,12 @@ if is_torch_available():
 
 @require_torch
 class GemmaModelTester(CausalLMModelTester):
-    config_class = GemmaConfig
     if is_torch_available():
         base_model_class = GemmaModel
-        causal_lm_class = GemmaForCausalLM
-        sequence_classification_class = GemmaForSequenceClassification
-        token_classification_class = GemmaForTokenClassification
 
 
 @require_torch
 class GemmaModelTest(CausalLMModelTest, unittest.TestCase):
-    all_model_classes = (
-        (GemmaModel, GemmaForCausalLM, GemmaForSequenceClassification, GemmaForTokenClassification)
-        if is_torch_available()
-        else ()
-    )
     pipeline_model_mapping = (
         {
             "feature-extraction": GemmaModel,
@@ -95,13 +85,6 @@ class GemmaModelTest(CausalLMModelTest, unittest.TestCase):
     ):
         return True
 
-    @require_flash_attn
-    @require_torch_gpu
-    @pytest.mark.flash_attn_test
-    @slow
-    def test_flash_attn_2_inference_equivalence_right_padding(self):
-        self.skipTest(reason="Gemma flash attention does not support right padding")
-
 
 @slow
 @require_torch_accelerator
