@@ -66,15 +66,12 @@ class Gemma3nProcessorTest(unittest.TestCase):
             tokenizer=tokenizer, feature_extractor=feature_extractor, image_processor=image_processor
         )
 
-        processor.save_pretrained(self.tmpdirname)
+        processor.save_pretrained(self.tmpdirname, legacy_serialization=False)
         processor = Gemma3nProcessor.from_pretrained(self.tmpdirname)
 
         self.assertIsInstance(processor.tokenizer, GemmaTokenizerFast)
         self.assertEqual(processor.tokenizer.get_vocab(), tokenizer.get_vocab())
 
-        # `disable_grouping` is a new attribute that got added on main while gemma3n was being released - so was
-        # not part of the saved processor
-        del processor.feature_extractor.disable_grouping
         self.assertIsInstance(processor.feature_extractor, Gemma3nAudioFeatureExtractor)
         self.assertEqual(processor.feature_extractor.to_json_string(), feature_extractor.to_json_string())
 
@@ -86,7 +83,7 @@ class Gemma3nProcessorTest(unittest.TestCase):
         processor = Gemma3nProcessor(
             tokenizer=tokenizer, feature_extractor=feature_extractor, image_processor=image_processor
         )
-        processor.save_pretrained(self.tmpdirname)
+        processor.save_pretrained(self.tmpdirname, legacy_serialization=False)
 
         tokenizer_add_kwargs = self.get_tokenizer(bos_token="(BOS-BOS)", eos_token="(EOS-EOS)")
         feature_extractor_add_kwargs = self.get_feature_extractor(dither=5.0, padding_value=1.0)
@@ -98,9 +95,6 @@ class Gemma3nProcessorTest(unittest.TestCase):
         self.assertEqual(processor.tokenizer.get_vocab(), tokenizer_add_kwargs.get_vocab())
         self.assertIsInstance(processor.tokenizer, GemmaTokenizerFast)
 
-        # `disable_grouping` is a new attribute that got added on main while gemma3n was being released - so was
-        # not part of the saved processor
-        del processor.feature_extractor.disable_grouping
         self.assertEqual(processor.feature_extractor.to_json_string(), feature_extractor_add_kwargs.to_json_string())
         self.assertIsInstance(processor.feature_extractor, Gemma3nAudioFeatureExtractor)
 
