@@ -15,7 +15,7 @@
 
 import unittest
 
-from transformers import AutoModelForCausalLM, AutoTokenizer, HeliumConfig, is_torch_available
+from transformers import AutoModelForCausalLM, AutoTokenizer, is_torch_available
 from transformers.testing_utils import (
     Expectations,
     require_read_token,
@@ -24,8 +24,7 @@ from transformers.testing_utils import (
     torch_device,
 )
 
-from ...test_configuration_common import ConfigTester
-from ..gemma.test_modeling_gemma import GemmaModelTest, GemmaModelTester
+from ..gemma.test_modeling_gemma import GemmaModelTester
 
 
 if is_torch_available():
@@ -41,20 +40,11 @@ if is_torch_available():
 
 class HeliumModelTester(GemmaModelTester):
     if is_torch_available():
-        config_class = HeliumConfig
-        model_class = HeliumModel
-        for_causal_lm_class = HeliumForCausalLM
-        for_sequence_class = HeliumForSequenceClassification
-        for_token_class = HeliumForTokenClassification
+        base_model_class = HeliumModel
 
 
 @require_torch
-class HeliumModelTest(GemmaModelTest, unittest.TestCase):
-    all_model_classes = (
-        (HeliumModel, HeliumForCausalLM, HeliumForSequenceClassification, HeliumForTokenClassification)
-        if is_torch_available()
-        else ()
-    )
+class HeliumModelTest(CausalLMModelTest, unittest.TestCase):
     pipeline_model_mapping = (
         {
             "feature-extraction": HeliumModel,
@@ -66,14 +56,10 @@ class HeliumModelTest(GemmaModelTest, unittest.TestCase):
         if is_torch_available()
         else {}
     )
-    test_headmasking = False
-    test_pruning = False
     _is_stateful = True
     model_split_percents = [0.5, 0.6]
 
-    def setUp(self):
-        self.model_tester = HeliumModelTester(self)
-        self.config_tester = ConfigTester(self, config_class=HeliumConfig, hidden_size=37)
+    model_tester_class = HeliumModelTester
 
 
 @slow
