@@ -16,7 +16,14 @@
 import unittest
 
 from transformers import LongformerConfig, is_torch_available
-from transformers.testing_utils import require_sentencepiece, require_tokenizers, require_torch, slow, torch_device
+from transformers.testing_utils import (
+    is_flaky,
+    require_sentencepiece,
+    require_tokenizers,
+    require_torch,
+    slow,
+    torch_device,
+)
 
 from ...test_configuration_common import ConfigTester
 from ...test_modeling_common import ModelTesterMixin, ids_tensor, random_attention_mask
@@ -355,6 +362,14 @@ class LongformerModelTest(ModelTesterMixin, PipelineTesterMixin, unittest.TestCa
         self.model_tester = LongformerModelTester(self)
         self.config_tester = ConfigTester(self, config_class=LongformerConfig, hidden_size=37)
 
+    # Without this, 0.01% failure rate.
+    @is_flaky(
+        max_attempts=2,
+        description="When `inputs_dict['attention_mask'][:, -1]` is all `0`s, we get shorter length along the last dimension of the output's `attentions`.",
+    )
+    def test_attention_outputs(self):
+        super().test_attention_outputs()
+
     def test_config(self):
         self.config_tester.run_common_tests()
 
