@@ -477,16 +477,16 @@ class Mask2FormerImageProcessingTest(ImageProcessingTestMixin, unittest.TestCase
 
     def test_post_process_semantic_segmentation(self):
         for image_processing_class in self.image_processor_list:
-            fature_extractor = image_processing_class(num_labels=self.image_processor_tester.num_classes)
+            feature_extractor = image_processing_class(num_labels=self.image_processor_tester.num_classes)
             outputs = self.image_processor_tester.get_fake_mask2former_outputs()
 
-            segmentation = fature_extractor.post_process_semantic_segmentation(outputs)
+            segmentation = feature_extractor.post_process_semantic_segmentation(outputs)
 
             self.assertEqual(len(segmentation), self.image_processor_tester.batch_size)
             self.assertEqual(segmentation[0].shape, (384, 384))
 
             target_sizes = [(1, 4) for i in range(self.image_processor_tester.batch_size)]
-            segmentation = fature_extractor.post_process_semantic_segmentation(outputs, target_sizes=target_sizes)
+            segmentation = feature_extractor.post_process_semantic_segmentation(outputs, target_sizes=target_sizes)
 
             self.assertEqual(segmentation[0].shape, target_sizes[0])
 
@@ -549,7 +549,7 @@ class Mask2FormerImageProcessingTest(ImageProcessingTestMixin, unittest.TestCase
                     continue
 
                 # Get number of segments to be fused
-                fuse_targets = [1 for el in el_unfused if el["label_id"] in {1}]
+                fuse_targets = [1 for el in el_unfused if el["label_id"] == 1]
                 num_to_fuse = 0 if len(fuse_targets) == 0 else sum(fuse_targets) - 1
                 # Expected number of segments after fusing
                 expected_num_segments = max([el["id"] for el in el_unfused]) - num_to_fuse
