@@ -17,13 +17,13 @@
 import unittest
 
 import numpy as np
-import requests
 
-from transformers.image_utils import PILImageResampling
+from transformers.image_utils import PILImageResampling, load_image
 from transformers.testing_utils import require_torch, require_vision
 from transformers.utils import is_torch_available, is_torchvision_available, is_vision_available
 
 from ...test_image_processing_common import ImageProcessingTestMixin
+from ...test_processing_common import url_to_local_path
 
 
 if is_vision_available():
@@ -298,9 +298,7 @@ class SmolVLMImageProcessingTest(ImageProcessingTestMixin, unittest.TestCase):
         if self.image_processing_class is None or self.fast_image_processing_class is None:
             self.skipTest(reason="Skipping slow/fast equivalence test as one of the image processors is not defined")
 
-        dummy_image = Image.open(
-            requests.get("http://images.cocodataset.org/val2017/000000039769.jpg", stream=True).raw
-        )
+        dummy_image = load_image(url_to_local_path("http://images.cocodataset.org/val2017/000000039769.jpg"))
         dummy_image = dummy_image.resize((100, 150))
         image_processor_slow = self.image_processing_class(
             **self.image_processor_dict, resample=PILImageResampling.BICUBIC
