@@ -152,7 +152,7 @@ class QuantoQuantizationTest(unittest.TestCase):
             self.model_name,
             device_map=self.device_map,
             quantization_config=quantization_config,
-            torch_dtype=torch.float32,
+            dtype=torch.float32,
         )
 
         self.tokenizer = AutoTokenizer.from_pretrained(self.model_name)
@@ -228,7 +228,7 @@ class QuantoQuantizationTest(unittest.TestCase):
             )
             # TODO: replace by the following when it works
             # quantized_model_from_saved = AutoModelForCausalLM.from_pretrained(
-            #     tmpdirname, torch_dtype=torch.float32, device_map="cpu"
+            #     tmpdirname, dtype=torch.float32, device_map="cpu"
             # )
             # self.check_inference_correctness(quantized_model_from_saved, device="cuda")
 
@@ -243,7 +243,7 @@ class QuantoQuantizationTest(unittest.TestCase):
                 "The model is quantized with QuantizationMethod.QUANTO and is not serializable", str(e.exception)
             )
             # quantized_model_from_saved = AutoModelForCausalLM.from_pretrained(
-            #     tmpdirname, torch_dtype=torch.float32, device_map="cpu"
+            #     tmpdirname, dtype=torch.float32, device_map="cpu"
             # )
             # self.check_inference_correctness(quantized_model_from_saved, device="cuda")
 
@@ -265,7 +265,7 @@ class QuantoQuantizationTest(unittest.TestCase):
         model = AutoModelForCausalLM.from_pretrained(
             self.model_name,
             device_map=self.device_map,
-            torch_dtype=torch.float32,
+            dtype=torch.float32,
         )
         # we do not quantize the lm_head since we don't do that in transformers
         quantize(model.transformer, weights=w_mapping[self.weights])
@@ -283,7 +283,7 @@ class QuantoQuantizationTest(unittest.TestCase):
         model = AutoModelForCausalLM.from_pretrained(
             self.model_name,
             device_map=self.device_map,
-            torch_dtype=torch.float32,
+            dtype=torch.float32,
         )
         # we do not quantize the lm_head since we don't do that in transformers
         quantize(model.transformer, weights=w_mapping[self.weights])
@@ -297,7 +297,7 @@ class QuantoQuantizationTest(unittest.TestCase):
             quantized_model_from_saved = AutoModelForCausalLM.from_pretrained(
                 tmpdirname,
                 device_map=self.device_map,
-                torch_dtype=torch.float32,
+                dtype=torch.float32,
             )
         self.check_same_model(model, quantized_model_from_saved)
         self.check_inference_correctness(quantized_model_from_saved, device="cuda")
@@ -392,12 +392,12 @@ class QuantoQuantizationSerializationTest(QuantoQuantizationTest):
             self.model_name,
             device_map=self.device_map,
             quantization_config=quantization_config,
-            torch_dtype=torch.float32,
+            dtype=torch.float32,
         )
         with tempfile.TemporaryDirectory() as tmpdirname:
             quantized_model.save_pretrained(tmpdirname, safe_serialization=False)
             self.quantized_model = AutoModelForCausalLM.from_pretrained(
-                tmpdirname, torch_dtype=torch.float32, device_map=self.device_map
+                tmpdirname, dtype=torch.float32, device_map=self.device_map
             )
 
         self.tokenizer = AutoTokenizer.from_pretrained(self.model_name)
@@ -422,7 +422,10 @@ class QuantoQuantizationQBitsTensorTest(QuantoQuantizationTest):
 
 
 class QuantoQuantizationQBitsTensorOffloadTest(QuantoQuantizationOffloadTest):
-    EXPECTED_OUTPUTS = "Hello my name is John, I am a professional photographer, I"
+    EXPECTED_OUTPUTS = [
+        "Hello my name is John, I am a professional photographer, I",  # CUDA output
+        "Hello my name is Nils, I am a student of the University",  # XPU output
+    ]
     weights = "int4"
 
 
@@ -463,7 +466,7 @@ class QuantoKVCacheQuantizationTest(unittest.TestCase):
             "unsloth/Llama-3.2-1B-Instruct", pad_token="</s>", padding_side="left"
         )
         model = LlamaForCausalLM.from_pretrained(
-            "unsloth/Llama-3.2-1B-Instruct", device_map="sequential", torch_dtype=torch.float16
+            "unsloth/Llama-3.2-1B-Instruct", device_map="sequential", dtype=torch.float16
         )
         inputs = tokenizer(prompts, return_tensors="pt", padding=True).to(torch_device)
 
