@@ -303,11 +303,9 @@ SPECIAL_CASES_TO_ALLOW = {
         "local_attention",
         "local_rope_theta",
     ],
-    # position_embedding_type not used and deprecated. Should be deleted in v4.55
-    "LayoutLMConfig": ["position_embedding_type"],
-    "MarkupLMConfig": ["position_embedding_type"],
     "SmolLM3Config": ["no_rope_layer_interval"],
     "Gemma3nVisionConfig": ["architecture", "do_pooling", "model_args"],  # this is for use in `timm`
+    "VaultGemmaConfig": ["tie_word_embeddings"],
 }
 
 
@@ -434,9 +432,9 @@ def check_attribute_being_used(config_class, attributes, default_value, source_s
         case_allowed = False
         for attribute in attributes:
             # Allow if the default value in the configuration class is different from the one in `PretrainedConfig`
-            if attribute in ["is_encoder_decoder"] and default_value is True:
+            if attribute == "is_encoder_decoder" and default_value is True:
                 case_allowed = True
-            elif attribute in ["tie_word_embeddings"] and default_value is False:
+            elif attribute == "tie_word_embeddings" and default_value is False:
                 case_allowed = True
 
             # Allow cases without checking the default value in the configuration class
