@@ -48,6 +48,7 @@ from transformers.models.auto.feature_extraction_auto import FEATURE_EXTRACTOR_M
 from transformers.models.auto.image_processing_auto import IMAGE_PROCESSOR_MAPPING_NAMES
 from transformers.models.auto.processing_auto import PROCESSOR_MAPPING_NAMES
 from transformers.models.auto.tokenization_auto import TOKENIZER_MAPPING_NAMES
+from transformers.testing_utils import _COMMON_MODEL_NAMES_MAP
 from transformers.utils import ENV_VARS_TRUE_VALUES, direct_transformers_import
 
 
@@ -71,6 +72,8 @@ PRIVATE_MODELS = [
     "Qwen2AudioEncoder",
     "Qwen2VisionTransformerPretrainedModel",
     "Qwen2_5_VisionTransformerPretrainedModel",
+    "Qwen3VLVisionModel",
+    "Qwen3VLMoeVisionModel",
     "SwitchTransformersStack",
     "TFDPRSpanPredictor",
     "MaskFormerSwinModel",
@@ -97,6 +100,9 @@ PRIVATE_MODELS = [
     "Glm4vVisionModel",
     "Glm4vMoeVisionModel",
     "EvollaSaProtPreTrainedModel",
+    "BltLocalEncoder",  # Building part of bigger (tested) model. Tested implicitly through BLTForCausalLM.
+    "BltLocalDecoder",  # Building part of bigger (tested) model. Tested implicitly through BLTForCausalLM.
+    "BltGlobalTransformer",  # Building part of bigger (tested) model. Tested implicitly through BLTForCausalLM.
     "Ovis2VisionModel",
 ]
 
@@ -144,13 +150,19 @@ IGNORE_NON_TESTED = (
         "BarkCausalModel",  # Building part of bigger (tested) model.
         "BarkModel",  # Does not have a forward signature - generation tested with integration tests.
         "Sam2HieraDetModel",  # Building part of bigger (tested) model.
-        "Sam2VideoModel",  # inherit from Sam2Model (tested).
+        "Sam2VideoModel",  # Partly tested in Sam2Model, not regular model.
+        "EdgeTamVisionModel",  # Building part of bigger (tested) model.
+        "EdgeTamVideoModel",  # Partly tested in EdgeTamModel, not regular model.
         "SeamlessM4TTextToUnitModel",  # Building part of bigger (tested) model.
         "SeamlessM4TCodeHifiGan",  # Building part of bigger (tested) model.
         "SeamlessM4TTextToUnitForConditionalGeneration",  # Building part of bigger (tested) model.
         "ChameleonVQVAE",  # VQVAE here is used only for encoding (discretizing) and is tested as part of bigger model
         "Qwen2VLModel",  # Building part of bigger (tested) model. Tested implicitly through Qwen2VLForConditionalGeneration.
         "Qwen2_5_VLModel",  # Building part of bigger (tested) model. Tested implicitly through Qwen2_5_VLForConditionalGeneration.
+        "Qwen3VLModel",  # Building part of bigger (tested) model. Tested implicitly through Qwen3VLForConditionalGeneration.
+        "Qwen3VLMoeModel",  # Building part of bigger (tested) model. Tested implicitly through Qwen3VLMoeForConditionalGeneration.
+        "Qwen3VLTextModel",  # Building part of bigger (tested) model.
+        "Qwen3VLMoeTextModel",  # Building part of bigger (tested) model.
         "Qwen2_5OmniForConditionalGeneration",  # Not a regular model. Testted in Qwen2_5OmniModelIntergrationTest
         "Qwen2_5OmniTalkerForConditionalGeneration",  #  Building part of bigger (tested) model. Tested implicitly through Qwen2_5OmniModelIntergrationTest.
         "Qwen2_5OmniTalkerModel",  # Building part of bigger (tested) model. Tested implicitly through Qwen2_5OmniModelIntergrationTest.
@@ -158,6 +170,16 @@ IGNORE_NON_TESTED = (
         "Qwen2_5OmniToken2WavModel",  # Building part of bigger (tested) model. Tested implicitly through Qwen2_5OmniModelIntergrationTest.
         "Qwen2_5OmniToken2WavDiTModel",  # Building part of bigger (tested) model. Tested implicitly through Qwen2_5OmniModelIntergrationTest.
         "Qwen2_5OmniToken2WavBigVGANModel",  # Building part of bigger (tested) model. Tested implicitly through Qwen2_5OmniModelIntergrationTest.
+        "Qwen3OmniMoeCode2Wav",  # Building part of bigger (tested) model. Tested implicitly through Qwen3OmniMoeForConditionalGenerationIntegrationTest.
+        "Qwen3OmniMoeCode2WavDecoderBlock",
+        "Qwen3OmniMoeText2Wav",  # Building part of bigger (tested) model. Tested implicitly through Qwen3OmniMoeForConditionalGenerationIntegrationTest.
+        "Qwen3OmniMoeTalkerCodePredictorModel",  # Building part of bigger (tested) model. Tested implicitly through Qwen3OmniMoeForConditionalGenerationIntegrationTest.
+        "Qwen3OmniMoeCode2WavTransformerModel",
+        "Qwen3OmniMoeTalkerForConditionalGeneration",
+        "Qwen3OmniMoeTalkerModel",
+        "Qwen3OmniMoeThinkerTextModel",
+        "Qwen3OmniMoeForConditionalGeneration",  # Bigger model tested through Qwen3OmniMoeForConditionalGenerationIntegrationTest.
+        "Qwen3OmniMoeTalkerCodePredictorModelForConditionalGeneration",  # Building part of bigger (tested) model. Tested implicitly through Qwen3OmniMoeForConditionalGenerationIntegrationTest.
         "MllamaTextModel",  # Building part of bigger (tested) model. # TODO: add tests
         "MllamaVisionModel",  # Building part of bigger (tested) model. # TODO: add tests
         "Llama4TextModel",  # Building part of bigger (tested) model. # TODO: add tests
@@ -174,6 +196,10 @@ IGNORE_NON_TESTED = (
         "CsmDepthDecoderForCausalLM",  # Building part of bigger (tested) model. Tested implicitly through CsmForConditionalGenerationIntegrationTest.
         "CsmDepthDecoderModel",  # Building part of bigger (tested) model. Tested implicitly through CsmForConditionalGenerationIntegrationTest.
         "CsmBackboneModel",  # Building part of bigger (tested) model. Tested implicitly through CsmForConditionalGenerationIntegrationTest.
+        "BltPatcher",  # Building part of bigger (tested) model. Tested implicitly through BLTForCausalLM.
+        "BltLocalEncoder",  # Building part of bigger (tested) model. Tested implicitly through BLTForCausalLM.
+        "BltLocalDecoder",  # Building part of bigger (tested) model. Tested implicitly through BLTForCausalLM.
+        "BltGlobalTransformer",  # Building part of bigger (tested) model. Tested implicitly through BLTForCausalLM.
         "Florence2VisionBackbone",  # Building part of bigger (tested) model. Tested implicitly through Florence2ForConditionalGeneration.
     ]
 )
@@ -201,6 +227,7 @@ TEST_FILES_WITH_NO_COMMON_TESTS = [
     "models/shieldgemma2/test_modeling_shieldgemma2.py",
     "models/llama4/test_modeling_llama4.py",
     "models/sam2_video/test_modeling_sam2_video.py",
+    "models/edgetam_video/test_modeling_edgetam_video.py",
 ]
 
 # Update this list for models that are not in any of the auto MODEL_XXX_MAPPING. Being in this list is an exception and
@@ -255,6 +282,8 @@ IGNORE_NON_AUTO_CONFIGURED = PRIVATE_MODELS.copy() + [
     "SamModel",
     "Sam2Model",
     "Sam2VideoModel",
+    "EdgeTamModel",
+    "EdgeTamVideoModel",
     "SamHQModel",
     "DPTForDepthEstimation",
     "DecisionTransformerGPT2Model",
@@ -396,7 +425,16 @@ IGNORE_NON_AUTO_CONFIGURED = PRIVATE_MODELS.copy() + [
     "CsmDepthDecoderModel",  # Building part of a bigger model
     "CsmDepthDecoderForCausalLM",  # Building part of a bigger model
     "CsmForConditionalGeneration",  # Building part of a bigger model
+    "BltPatcher",  # Building part of a bigger model, tested implicitly through BltForCausalLM
     "Florence2VisionBackbone",  # Building part of a bigger model
+    "Qwen3OmniMoeCode2Wav",  # Building part of a bigger model
+    "Qwen3OmniMoeCode2WavTransformerModel",  # Building part of a bigger model
+    "Qwen3OmniMoeTalkerCodePredictorModel",  # Building part of a bigger model
+    "Qwen3OmniMoeTalkerCodePredictorModelForConditionalGeneration",  # Building part of a bigger model
+    "Qwen3OmniMoeTalkerForConditionalGeneration",  # Building part of a bigger model
+    "Qwen3OmniMoeTalkerModel",  # Building part of a bigger model
+    "Qwen3OmniMoeThinkerForConditionalGeneration",  # Building part of a bigger model
+    "Qwen3OmniMoeThinkerTextModel",  # Building part of a bigger model
 ]
 
 # DO NOT edit this list!
@@ -628,7 +666,7 @@ def get_model_test_files() -> list[str]:
 
 # This is a bit hacky but I didn't find a way to import the test_file as a module and read inside the tester class
 # for the all_model_classes variable.
-def find_tested_models(test_file: str) -> list[str]:
+def find_tested_models(test_file: str) -> set[str]:
     """
     Parse the content of test_file to detect what's in `all_model_classes`. This detects the models that inherit from
     the common test class.
@@ -637,21 +675,46 @@ def find_tested_models(test_file: str) -> list[str]:
         test_file (`str`): The path to the test file to check
 
     Returns:
-        `List[str]`: The list of models tested in that file.
+        `Set[str]`: The set of models tested in that file.
     """
     with open(os.path.join(PATH_TO_TESTS, test_file), "r", encoding="utf-8", newline="\n") as f:
         content = f.read()
+
+    model_tested = set()
+
     all_models = re.findall(r"all_model_classes\s+=\s+\(\s*\(([^\)]*)\)", content)
     # Check with one less parenthesis as well
     all_models += re.findall(r"all_model_classes\s+=\s+\(([^\)]*)\)", content)
     if len(all_models) > 0:
-        model_tested = []
         for entry in all_models:
             for line in entry.split(","):
                 name = line.strip()
                 if len(name) > 0:
-                    model_tested.append(name)
-        return model_tested
+                    model_tested.add(name)
+
+    # Models that inherit from `CausalLMModelTester` don't need to set `all_model_classes` -- it is built from other
+    # attributes by default.
+    if "CausalLMModelTester" in content:
+        base_model_class = re.findall(r"base_model_class\s+=.*", content)  # Required attribute
+        base_class = base_model_class[0].split("=")[1].strip()
+        model_tested.add(base_class)
+
+        model_name = base_class.replace("Model", "")
+        # Optional attributes: if not set explicitly, the tester will attempt to infer and use the corresponding class
+        for test_class_type in [
+            "causal_lm_class",
+            "sequence_classification_class",
+            "question_answering_class",
+            "token_classification_class",
+        ]:
+            tested_class = re.findall(rf"{test_class_type}\s+=.*", content)
+            if tested_class:
+                tested_class = tested_class[0].split("=")[1].strip()
+            else:
+                tested_class = model_name + _COMMON_MODEL_NAMES_MAP[test_class_type]
+            model_tested.add(tested_class)
+
+    return model_tested
 
 
 def should_be_tested(model_name: str) -> bool:
@@ -676,22 +739,24 @@ def check_models_are_tested(module: types.ModuleType, test_file: str) -> list[st
     # XxxPreTrainedModel are not tested
     defined_models = get_models(module)
     tested_models = find_tested_models(test_file)
-    if tested_models is None:
+    if len(tested_models) == 0:
         if test_file.replace(os.path.sep, "/") in TEST_FILES_WITH_NO_COMMON_TESTS:
             return
         return [
-            f"{test_file} should define `all_model_classes` to apply common tests to the models it tests. "
-            + "If this intentional, add the test filename to `TEST_FILES_WITH_NO_COMMON_TESTS` in the file "
-            + "`utils/check_repo.py`."
+            f"{test_file} should define `all_model_classes` or inherit from `CausalLMModelTester` (and fill in the "
+            "model class attributes) to apply common tests to the models it tests. "
+            "If this intentional, add the test filename to `TEST_FILES_WITH_NO_COMMON_TESTS` in the file "
+            "`utils/check_repo.py`."
         ]
     failures = []
     for model_name, _ in defined_models:
         if model_name not in tested_models and should_be_tested(model_name):
             failures.append(
                 f"{model_name} is defined in {module.__name__} but is not tested in "
-                + f"{os.path.join(PATH_TO_TESTS, test_file)}. Add it to the all_model_classes in that file."
-                + "If common tests should not applied to that model, add its name to `IGNORE_NON_TESTED`"
-                + "in the file `utils/check_repo.py`."
+                f"{os.path.join(PATH_TO_TESTS, test_file)}. Add it to the `all_model_classes` in that file or, if "
+                "it inherits from `CausalLMModelTester`, fill in the model class attributes. "
+                "If common tests should not applied to that model, add its name to `IGNORE_NON_TESTED`"
+                "in the file `utils/check_repo.py`."
             )
     return failures
 
@@ -891,7 +956,7 @@ def check_all_auto_mappings_importable():
 
 def check_objects_being_equally_in_main_init():
     """
-    Check if a (TensorFlow or Flax) object is in the main __init__ iif its counterpart in PyTorch is.
+    Check if a (TensorFlow or Flax) object is in the main __init__ if its counterpart in PyTorch is.
     """
     attrs = dir(transformers)
 
@@ -1142,6 +1207,9 @@ def ignore_undocumented(name: str) -> bool:
     # MMBT model does not really work.
     if name.startswith("MMBT"):
         return True
+    # BLT models are internal building blocks, tested implicitly through BltForCausalLM
+    if name.startswith("Blt"):
+        return True
     if name in SHOULD_HAVE_THEIR_OWN_PAGE:
         return True
     return False
