@@ -5,7 +5,8 @@ IMPORTANT_MODELS = [
     "gpt2",
     "t5",
     "modernbert",
-    "vit,clip",
+    "vit",
+    "clip",
     "detr",
     "table_transformer",
     "got_ocr2",
